@@ -11,8 +11,8 @@
 #include <QString>
 
 class RootItem;
-
 class TtRssFeed;
+class Label;
 
 class TtRssResponse {
   public:
@@ -41,6 +41,13 @@ class TtRssLoginResponse : public TtRssResponse {
     QString sessionId() const;
 };
 
+class TtRssGetLabelsResponse : public TtRssResponse {
+  public:
+    explicit TtRssGetLabelsResponse(const QString& raw_content = QString());
+
+    QList<RootItem*> labels() const;
+};
+
 class TtRssGetFeedsCategoriesResponse : public TtRssResponse {
   public:
     explicit TtRssGetFeedsCategoriesResponse(const QString& raw_content = QString());
@@ -52,12 +59,14 @@ class TtRssGetFeedsCategoriesResponse : public TtRssResponse {
     RootItem* feedsCategories(bool obtain_icons, QString base_address = QString()) const;
 };
 
+class ServiceRoot;
+
 class TtRssGetHeadlinesResponse : public TtRssResponse {
   public:
     explicit TtRssGetHeadlinesResponse(const QString& raw_content = QString());
     virtual ~TtRssGetHeadlinesResponse();
 
-    QList<Message> messages() const;
+    QList<Message> messages(ServiceRoot* root) const;
 };
 
 class TtRssUpdateArticleResponse : public TtRssResponse {
@@ -139,6 +148,9 @@ class TtRssNetworkFactory {
     // Logs user out.
     TtRssResponse logout();
 
+    // Gets list of labels from the server.
+    TtRssGetLabelsResponse getLabels();
+
     // Gets feeds from the server.
     TtRssGetFeedsCategoriesResponse getFeedsCategories();
 
@@ -147,6 +159,8 @@ class TtRssNetworkFactory {
                                            bool show_content, bool include_attachments,
                                            bool sanitize, bool unread_only);
 
+    TtRssResponse setArticleLabel(const QStringList& article_ids, const QString& label_custom_id, bool assign);
+
     TtRssUpdateArticleResponse updateArticles(const QStringList& ids, UpdateArticle::OperatingField field,
                                               UpdateArticle::Mode mode, bool async = true);
 
